summaryrefslogtreecommitdiffstats
path: root/kftpgrabber/src/kftpqueue.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-07-24 15:27:17 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-07-24 15:27:17 -0500
commit883a1fc629f00e9a41efad8514afd1ccf259d8c2 (patch)
tree53191c33748f9cd949a2eb86a64fbedc86c5ac75 /kftpgrabber/src/kftpqueue.h
parent1385303ea163214e30825730ac0fbcc27f9634aa (diff)
downloadkftpgrabber-883a1fc629f00e9a41efad8514afd1ccf259d8c2.tar.gz
kftpgrabber-883a1fc629f00e9a41efad8514afd1ccf259d8c2.zip
Convert to TDE R14 API
Diffstat (limited to 'kftpgrabber/src/kftpqueue.h')
-rw-r--r--kftpgrabber/src/kftpqueue.h40
1 files changed, 20 insertions, 20 deletions
diff --git a/kftpgrabber/src/kftpqueue.h b/kftpgrabber/src/kftpqueue.h
index d20d817..fc47572 100644
--- a/kftpgrabber/src/kftpqueue.h
+++ b/kftpgrabber/src/kftpqueue.h
@@ -36,12 +36,12 @@
#ifndef KFTPQUEUE_H
#define KFTPQUEUE_H
-#include <qstring.h>
-#include <qvaluelist.h>
-#include <qtimer.h>
-#include <qcache.h>
-#include <qmap.h>
-#include <qpair.h>
+#include <ntqstring.h>
+#include <ntqvaluelist.h>
+#include <ntqtimer.h>
+#include <ntqcache.h>
+#include <ntqmap.h>
+#include <ntqpair.h>
#include <kurl.h>
#include <kurldrag.h>
@@ -70,7 +70,7 @@ namespace KFTPSession {
class KFTPQueueConverter;
-typedef QPtrList<KFTPQueue::Transfer> KFTPQueueTransfers;
+typedef TQPtrList<KFTPQueue::Transfer> KFTPQueueTransfers;
namespace KFTPQueue {
@@ -117,7 +117,7 @@ private:
KURL m_source;
KURL m_dest;
- QString m_hash;
+ TQString m_hash;
};
/**
@@ -181,7 +181,7 @@ private:
*
* @author Jernej Kos <kostko@unimatrix-one.org>
*/
-class Manager : public QObject {
+class Manager : public TQObject {
Q_OBJECT
friend class KFTPSession::Session;
friend class KFTPSession::Connection;
@@ -329,9 +329,9 @@ public:
/**
* Returns the list of failed transfers.
*
* @return The QPtrList of FailedTransfer objects
*/
- QPtrList<KFTPQueue::FailedTransfer> *getFailedTransferList() { return &m_failedTransfers; }
+ TQPtrList<KFTPQueue::FailedTransfer> *getFailedTransferList() { return &m_failedTransfers; }
/**
* Return the queue converter (exporter).
@@ -421,7 +421,7 @@ public:
*
* @return The next available transfer id
*/
- long nextTransferId() { return m_lastQID++; }
+ long nextTransferId() { return m_lastTQID++; }
/**
* Set a default action to take when encountering an existing file situation. Note that
@@ -449,7 +449,7 @@ public:
* @return A FileExistsWakeupEvent that will be sent to the engine
*/
KFTPEngine::FileExistsWakeupEvent *fileExistsAction(KFTPQueue::TransferFile *transfer,
- QValueList<KFTPEngine::DirectoryEntry> stat);
+ TQValueList<KFTPEngine::DirectoryEntry> stat);
/**
* Spawn a new transfer.
@@ -465,7 +465,7 @@ public:
* @return A valid KFTPQueue::Transfer instance
*/
KFTPQueue::Transfer *spawnTransfer(KURL sourceUrl, KURL destinationUrl, filesize_t size, bool dir,
- bool ignoreSkip = false, bool insertToQueue = true, QObject *parent = 0L, bool noScan = false);
+ bool ignoreSkip = false, bool insertToQueue = true, TQObject *parent = 0L, bool noScan = false);
protected:
/**
* Global class instance.
@@ -491,14 +491,14 @@ protected:
void processUserDialogRequest();
private:
QueueObject *m_topLevel;
- QCache<QueueObject> m_queueObjectCache;
+ TQCache<QueueObject> m_queueObjectCache;
- QMap<pid_t, OpenedFile> m_editProcessList;
- QPtrList<KFTPQueue::FailedTransfer> m_failedTransfers;
+ TQMap<pid_t, OpenedFile> m_editProcessList;
+ TQPtrList<KFTPQueue::FailedTransfer> m_failedTransfers;
KFTPQueueProcessor *m_queueProc;
KFTPQueueConverter *m_converter;
- long m_lastQID;
+ long m_lastTQID;
bool m_emitUpdate;
bool m_processingQueue;
@@ -507,12 +507,12 @@ private:
bool m_feDialogOpen;
FEAction m_defaultFeAction;
- QPtrList<UserDialogRequest> m_userDialogRequests;
+ TQPtrList<UserDialogRequest> m_userDialogRequests;
private slots:
void slotQueueProcessingComplete();
void slotQueueProcessingAborted();
- void slotEditProcessTerminated(KProcess *p);
+ void slotEditProcessTerminated(TDEProcess *p);
signals:
void newSite(KFTPQueue::Site*);
void newTransfer(KFTPQueue::Transfer*);
@@ -329,9 +329,9 @@ public:
* Returns the list of failed transfers.
*
- * @return The QPtrList of FailedTransfer objects
+ * @return The TQPtrList of FailedTransfer objects
*/